@@ -9,6 +9,10 @@
 #'   The objects, which should be visible inside `.fn`.
 #' @param .parent (`environment`)\cr
 #'   Parent environment to look up names. Default to [topenv()].
+#' @param .compile (`logical(1)`)\cr
+#'   Whether to jit-compile the function.
+#'   In case the function is already compiled.
+#'   If the input function `.fn` is compiled, this has no effect, and the output function will always be compiled.
 #'
 #' @export
 #' @examples
@@ -24,8 +28,20 @@
 #' z = 300
 #' f = meta_f(1)
 #' f()
-crate = function(.fn, ..., .parent = topenv()) {
+crate = function(.fn, ..., .parent = topenv(), .compile = TRUE) {
+  assert_flag(.compile)
+  .compile = .compile || is_compiled(.fn)
   nn = map_chr(substitute(list(...)), as.character)[-1L]
   environment(.fn) = list2env(setNames(list(...), nn), parent = .parent)
-  .fn
+  if (.compile) {
+    .fn = compiler::cmpfun(.fn)
+  }
+  return(.fn)
+}
+
+is_compiled = function(x) {
+  tryCatch({
+    capture.output(compiler::disassemble(x))
+    TRUE
+  }, error = function(e) FALSE)
 }
