@@ -31,17 +31,6 @@ test_that("Dictionary clones R6", {
   expect_false(data.table::address(foo) == data.table::address(d$get("f")))
 })
 
-test_that("Dictionary required args", {
-  foo = R6Class("Foo", public = list(x = 0))
-  x = Dictionary$new()
-  x$add("a", foo)
-  x$add("b", foo, required_args = "c")
-
-  expect_equal(x$required_args("a"), character())
-  expect_equal(x$required_args("b"), "c")
-  expect_equal(x$required_args("c"), NULL)
-})
-
 test_that("Dictionary throws exception on unnamed args", {
   foo = R6Class("Foo", public = list(x = 0))
   x = Dictionary$new()
@@ -128,3 +117,14 @@ test_that("avoid unintended partial argument matching", {
   expect_r6(a, "A")
   expect_equal(a$d, 1)
 })
+
+
+test_that("prototype_args works", {
+  A = R6Class("A", public = list(x = NULL, initialize = function(x) self$x = x))
+  d = Dictionary$new()
+  d$add("a", A, .prototype_args = list(x = 1))
+  expect_identical(d$prototype_args("a"), list(x = 1))
+  a = d$get("a", .prototype = TRUE)
+  expect_identical(a$x, 1)
+  expect_identical(d$prototype_args("a"), list(x = 1))
+})
